@@ -1455,6 +1455,8 @@ class Ticket(TimeStampedModel):
                                         choices=PREDECESSOR_TYPES)
     lag_days = models.IntegerField(blank=True, null=True)
     lag_non_working_days_flag = models.BooleanField(default=False)
+    estimated_start_date = models.DateTimeField(blank=True, null=True)
+    wbs_code = models.CharField(blank=True, null=True, max_length=50)
     udf = models.JSONField(blank=True, null=True)
 
     ticket_predecessor = models.ForeignKey(
